@@ -27,9 +27,7 @@
 
 #include <KDebug>
 #include <KLocale>
-#include <KProcess>
 #include <KTempDir>
-#include <KTemporaryFile>
 #include <KToolInvocation>
 #include <KMessageBox>
 #include <QDir>
@@ -385,6 +383,3 @@ KGpgCaff::run()
 
 	d->reexportKey(d->m_allids.first());
 }
-
-#include "caff.moc"
-#include "caff_p.moc"
